@@ -2375,10 +2375,11 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
         if (null == trace) {
             return;
         }
+        final String lineSeparator = System.getProperty("line.separator");
         for (final StackTraceElement ste : trace) {
             final String className = ste.getClassName();
             if (null != className) {
-                sb.append("\tat ").append(className).append('.').append(ste.getMethodName());
+                sb.append("    at ").append(className).append('.').append(ste.getMethodName());
                 if (ste.isNativeMethod()) {
                     sb.append("(Native Method)");
                 } else {
@@ -2394,7 +2395,7 @@ public final class AjpProcessor implements com.openexchange.ajp13.watcher.Task {
                         sb.append(')');
                     }
                 }
-                sb.append('\n');
+                sb.append(lineSeparator);
             }
         }
     }
