@@ -53,11 +53,11 @@ import java.net.Socket;
 import javax.management.NotCompliantMBeanException;
 import com.openexchange.ajp13.AJPv13Config;
 import com.openexchange.ajp13.AJPv13ServiceRegistry;
+import com.openexchange.ajp13.IAJPv13SocketHandler;
 import com.openexchange.ajp13.coyote.AjpProcessor;
 import com.openexchange.ajp13.coyote.Constants;
 import com.openexchange.ajp13.monitoring.AJPv13Monitors;
-import com.openexchange.ajp13.najp.AJPv13TaskMonitor;
-import com.openexchange.ajp13.najp.IAJPv13SocketHandler;
+import com.openexchange.ajp13.watcher.AJPv13TaskMonitor;
 import com.openexchange.ajp13.watcher.AJPv13TaskWatcher;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.configuration.ServerConfig;
